Range-v3: Member List

Range-v3 Range algorithms, views, and actions for the Standard Library |

ranges::v3::overloaded< First, Rest... > Member List

This is the complete list of members for ranges::v3::overloaded< First, Rest... >, including all inherited members.

operator()(Args &&...args) noexcept(noexcept(decltype(invoke(std::declval< First &>(), static_cast< Args &&>(args)...))(invoke(std::declval< First &>(), static_cast< Args &&>(args)...)))) -> decltype(invoke(std::declval< First &>(), static_cast< Args &&>(args)...)) (defined in ranges::v3::overloaded< First, Rest... >) | ranges::v3::overloaded< First, Rest... > |
operator()(Args &&...args) const noexcept(noexcept(decltype(invoke(std::declval< First const &>(), static_cast< Args &&>(args)...))(invoke(std::declval< First const &>(), static_cast< Args &&>(args)...)))) -> decltype(invoke(std::declval< First const &>(), static_cast< Args &&>(args)...)) (defined in ranges::v3::overloaded< First, Rest... >) | ranges::v3::overloaded< First, Rest... > |
operator()(Args &&...args) noexcept(noexcept(decltype(std::declval< overloaded< Rest... > &>()(static_cast< Args &&>(args)...))(std::declval< overloaded< Rest... > &>()(static_cast< Args &&>(args)...)))) -> decltype(std::declval< overloaded< Rest... > &>()(static_cast< Args &&>(args)...)) (defined in ranges::v3::overloaded< First, Rest... >) | ranges::v3::overloaded< First, Rest... > |
operator()(Args &&...args) const noexcept(noexcept(decltype(std::declval< overloaded< Rest... > const &>()(static_cast< Args &&>(args)...))(std::declval< overloaded< Rest... > const &>()(static_cast< Args &&>(args)...)))) -> decltype(std::declval< overloaded< Rest... > const &>()(static_cast< Args &&>(args)...)) (defined in ranges::v3::overloaded< First, Rest... >) | ranges::v3::overloaded< First, Rest... > |
overloaded()=default (defined in ranges::v3::overloaded< First, Rest... >) | ranges::v3::overloaded< First, Rest... > |
overloaded(First first, Rest... rest) (defined in ranges::v3::overloaded< First, Rest... >) | ranges::v3::overloaded< First, Rest... > |